@@ -121,7 +121,7 @@ static gint addrgather_dlg_delete_event(
 static gboolean addrgather_dlg_key_pressed(
 	GtkWidget *widget, GdkEventKey *event, gpointer data )
 {
-	if( event && event->keyval == GDK_Escape ) {
+	if( event && event->keyval == GDK_KEY_Escape ) {
 		addrgather_dlg.cancelled = TRUE;
 		gtk_main_quit();
 	}
@@ -271,11 +271,10 @@ static void addrgather_page_fields(gint pageNum, gchar *pageLbl)
 	GtkWidget *frameHeader;
 	GtkWidget *checkHeader[NUM_FIELDS];
 	GtkWidget *spinbtnFolder;
-	GtkObject *adjFolder;
+	GtkAdjustment *adjFolder;
 	GtkWidget *checkRecurse;
 	gint top;
 	gint i;
-	CLAWS_TIP_DECL();
 
 	/* Container */
 	vbox = gtk_vbox_new(FALSE, 6);
