@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2009 Match Grun and the Claws Mail team
+ * Copyright (C) 2002-2011 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -529,7 +529,7 @@ static void addrharvest_parse_address(
 			}
 			else {
 				name = buffer;
-				name = conv_unmime_header(buffer, NULL);
+				name = conv_unmime_header(buffer, NULL, TRUE);
 			}
 
 			/* Insert into address book */
