@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ PrefFile *prefs_read_open(const gchar *path)
 	PrefFile *pfile;
 	FILE *fp;
 
-	g_return_val_if_fail(path != NULL, NULL);
+	cm_return_val_if_fail(path != NULL, NULL);
 
 	if ((fp = g_fopen(path, "rb")) == NULL) {
 		FILE_OP_ERROR(path, "fopen");
@@ -73,7 +73,7 @@ PrefFile *prefs_write_open(const gchar *path)
 	gchar *tmppath;
 	FILE *fp;
 
-	g_return_val_if_fail(path != NULL, NULL);
+	cm_return_val_if_fail(path != NULL, NULL);
 
 	if (prefs_is_readonly(path)) {
 		g_warning("no permission - %s\n", path);
@@ -101,6 +101,8 @@ PrefFile *prefs_write_open(const gchar *path)
 	return pfile;
 }
 
+gboolean prefs_common_get_flush_metadata (void);
+
 /*!
  *\brief	Close and free preferences file
  *		Creates final file from temp, creates backup
@@ -124,7 +126,7 @@ gint prefs_file_close(PrefFile *pfile)
 	gchar *bakpath = NULL;
 	gchar buf[BUFFSIZE];
 
-	g_return_val_if_fail(pfile != NULL, -1);
+	cm_return_val_if_fail(pfile != NULL, -1);
 
 	fp = pfile->fp;
 	orig_fp = pfile->orig_fp;
@@ -162,6 +164,17 @@ gint prefs_file_close(PrefFile *pfile)
 	}
 
 	tmppath = g_strconcat(path, ".tmp", NULL);
+
+	
+	if (prefs_common_get_flush_metadata() && fsync(fileno(fp)) < 0) {
+		FILE_OP_ERROR(tmppath, "fsync");
+		fclose(fp);
+		claws_unlink(tmppath);
+		g_free(path);
+		g_free(tmppath);
+		return -1;
+	}
+
 	if (fclose(fp) == EOF) {
 		FILE_OP_ERROR(tmppath, "fclose");
 		claws_unlink(tmppath);
@@ -214,7 +227,7 @@ gint prefs_file_close_revert(PrefFile *pfile)
 {
 	gchar *tmppath = NULL;
 
-	g_return_val_if_fail(pfile != NULL, -1);
+	cm_return_val_if_fail(pfile != NULL, -1);
 
 	if (pfile->orig_fp)
 		fclose(pfile->orig_fp);
