@@ -78,7 +78,7 @@ static gint edit_jpilot_delete_event( GtkWidget *widget, GdkEventAny *event, gbo
 }
 
 static gboolean edit_jpilot_key_pressed( GtkWidget *widget, GdkEventKey *event, gboolean *cancelled ) {
-	if (event && event->keyval == GDK_Escape) {
+	if (event && event->keyval == GDK_KEY_Escape) {
 		*cancelled = TRUE;
 		gtk_main_quit();
 	}
