@@ -90,12 +90,12 @@ static struct TagApplyWindow
 } applywindow;
 
 #define APPLYWINDOW_LOCK() {								\
-	gdk_window_set_cursor(applywindow.window->window, applywindow.watch_cursor);	\
+	gdk_window_set_cursor(gtk_widget_get_window(applywindow.window), applywindow.watch_cursor);	\
 	applywindow.busy = TRUE;							\
 }
 
 #define APPLYWINDOW_UNLOCK() {								\
-	gdk_window_set_cursor(applywindow.window->window, NULL);			\
+	gdk_window_set_cursor(gtk_widget_get_window(applywindow.window), NULL);			\
 	applywindow.busy = FALSE;							\
 }
 
@@ -488,9 +488,9 @@ static gboolean apply_window_key_pressed(GtkWidget *widget, GdkEventKey *event,
 {
 	if (applywindow.busy)
 		return FALSE;
-	if (event && event->keyval == GDK_Escape)
+	if (event && event->keyval == GDK_KEY_Escape)
 		apply_window_close();
-	else if (event && event->keyval == GDK_Delete)
+	else if (event && event->keyval == GDK_KEY_Delete)
 		apply_popup_delete(NULL, NULL);
 	return FALSE;
 }
@@ -500,7 +500,7 @@ static gboolean apply_window_add_key_pressed(GtkWidget *widget, GdkEventKey *eve
 	if (applywindow.busy)
 		return FALSE;
 
-	if (event && (event->keyval == GDK_KP_Enter || event->keyval == GDK_Return)) {
+	if (event && (event->keyval == GDK_KEY_KP_Enter || event->keyval == GDK_KEY_Return)) {
 		apply_window_add_tag();
 		gtk_entry_set_text(GTK_ENTRY(applywindow.add_entry), "");
 		gtk_widget_grab_focus(applywindow.taglist);
