@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2009 Match Grun and the Claws Mail team
+ * Copyright (C) 2002-2011 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,10 @@
 #  include "config.h"
 #endif
 
+#ifdef USE_PTHREAD
+#include <pthread.h>
+#endif
+
 #include <sys/stat.h>
 #include <dirent.h>
 #include <errno.h>
