@@ -40,11 +40,11 @@ static gboolean quote_colors_set_dialog_key_pressed(GtkWidget *widget,
 						GdkEventKey *event,
 						gpointer data)
 {
-	if (event && event->keyval == GDK_Escape) {
+	if (event && event->keyval == GDK_KEY_Escape) {
 		*((gint *) data) = 1;
 		gtk_main_quit();
 		return TRUE;
-	} else if (event && event->keyval == GDK_Return) {
+	} else if (event && event->keyval == GDK_KEY_Return) {
 		*((gint *) data) = 0;
 		gtk_main_quit();
 		return FALSE;
@@ -56,6 +56,7 @@ gint colorsel_select_color_rgb(gchar *title, gint rgbvalue)
 {
 	GdkColor color;
 	GtkColorSelectionDialog *color_dialog;
+	GtkWidget *ok_button, *cancel_button;
 	gint result;
 
 	color_dialog = GTK_COLOR_SELECTION_DIALOG(gtk_color_selection_dialog_new(title));
@@ -63,10 +64,15 @@ gint colorsel_select_color_rgb(gchar *title, gint rgbvalue)
 	gtk_window_set_resizable(GTK_WINDOW(color_dialog), FALSE);
 	manage_window_set_transient(GTK_WINDOW(color_dialog));
 
-	g_signal_connect(G_OBJECT(GTK_COLOR_SELECTION_DIALOG(color_dialog)->ok_button),
+	g_object_get(color_dialog,
+		"ok-button", &ok_button,
+		"cancel-button", &cancel_button,
+		NULL);
+
+	g_signal_connect(G_OBJECT(ok_button),
 			 "clicked", 
 			 G_CALLBACK(quote_colors_set_dialog_ok), &result);
-	g_signal_connect(G_OBJECT(GTK_COLOR_SELECTION_DIALOG(color_dialog)->cancel_button),
+	g_signal_connect(G_OBJECT(cancel_button),
 			 "clicked", 
 			 G_CALLBACK(quote_colors_set_dialog_cancel), &result);
 	g_signal_connect(G_OBJECT(color_dialog), "key_press_event",
@@ -74,14 +80,15 @@ gint colorsel_select_color_rgb(gchar *title, gint rgbvalue)
 
 	/* preselect the previous color in the color selection dialog */
 	gtkut_convert_int_to_gdk_color(rgbvalue, &color);
-	gtk_color_selection_set_current_color
-		(GTK_COLOR_SELECTION(color_dialog->colorsel), &color);
+	gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(
+		gtk_color_selection_dialog_get_color_selection(color_dialog)), &color);
 
 	gtk_widget_show(GTK_WIDGET(color_dialog));
 	gtk_main();
 
 	if (result == 0) {
-		gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(color_dialog->colorsel), &color);
+		gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(
+			gtk_color_selection_dialog_get_color_selection(color_dialog)), &color);
 		rgbvalue = gtkut_convert_gdk_color_to_int(&color);
 	}
 
