@@ -203,14 +203,14 @@ gboolean combobox_set_value_from_arrow_key(GtkComboBox *combobox,
 	if (gtk_combo_box_get_active_iter(combobox, &iter)) {
 		/* if current text is in list, get prev or next one */
 
-		if (keyval == GDK_Up) {
+		if (keyval == GDK_KEY_Up) {
 			gchar *text = gtk_combo_box_get_active_text(combobox);
 			if (!text)
 				text = gtk_editable_get_chars(GTK_EDITABLE(gtk_bin_get_child(GTK_BIN(combobox))),0,-1);
 			valid = gtkut_tree_model_text_iter_prev(model, &iter, text);
 			g_free(text);
 		} else
-		if (keyval == GDK_Down)
+		if (keyval == GDK_KEY_Down)
 			valid = gtk_tree_model_iter_next(model, &iter);
 
 		if (valid)
@@ -219,10 +219,10 @@ gboolean combobox_set_value_from_arrow_key(GtkComboBox *combobox,
 	} else {
 		/* current text is not in list, get first or next one */
 
-		if (keyval == GDK_Up)
+		if (keyval == GDK_KEY_Up)
 			valid = gtkut_tree_model_get_iter_last(model, &iter);
 		else
-		if (keyval == GDK_Down)
+		if (keyval == GDK_KEY_Down)
 			valid = gtk_tree_model_get_iter_first(model, &iter);
 
 		if (valid)
