@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail Team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -222,11 +222,11 @@ static gboolean prefswindow_key_pressed(GtkWidget *widget, GdkEventKey *event,
 
 	if (event) {
 		switch (event->keyval) {
-			case GDK_Escape :
+			case GDK_KEY_Escape :
 				cancel_button_clicked(NULL, data);
 				break;
-			case GDK_Return : 
-			case GDK_KP_Enter :
+			case GDK_KEY_Return : 
+			case GDK_KEY_KP_Enter :
 				focused_child = gtkut_get_focused_child
 					(GTK_CONTAINER(data->notebook));
 				/* Press ok, if the focused child is not a text view
@@ -305,7 +305,9 @@ static void prefswindow_build_page(PrefsWindow *prefswindow, PrefsPage *page)
 
 		gtk_container_add(GTK_CONTAINER(prefswindow->notebook), scrolledwin);
 		tmp = gtk_bin_get_child(GTK_BIN(scrolledwin));
-		gtk_viewport_set_shadow_type(GTK_VIEWPORT(tmp), GTK_SHADOW_NONE);
+
+		gtk_widget_realize(tmp);
+		gtk_widget_realize(page->widget);
 		
 		page->widget	= scrolledwin;
 		page->page_open	= TRUE;
@@ -598,7 +600,7 @@ void prefswindow_open_full(const gchar *title, GSList *prefs_pages,
 #endif
 	adj = gtk_scrolled_window_get_vadjustment(
 			GTK_SCROLLED_WINDOW(prefswindow->scrolledwindow1));
-	gtk_adjustment_set_value(adj, adj->lower);
+	gtk_adjustment_set_value(adj, gtk_adjustment_get_lower(adj));
 	gtk_adjustment_changed(adj);
 }
 
@@ -684,6 +686,7 @@ static gboolean prefswindow_row_selected(GtkTreeSelection *selector,
 	PrefsTreeNode *prefsnode;
 	PrefsPage *page;
 	PrefsWindow *prefswindow = (PrefsWindow *) data;
+	gfloat lower;
 	gchar *labeltext;
 	gint pagenum, i;
 	GtkTreeIter iter;
@@ -728,11 +731,12 @@ static gboolean prefswindow_row_selected(GtkTreeSelection *selector,
 
 	adj = gtk_scrolled_window_get_vadjustment(
 			GTK_SCROLLED_WINDOW(page->widget));
-	gtk_adjustment_set_value(adj, adj->lower);
+	lower = gtk_adjustment_get_lower(adj);
+	gtk_adjustment_set_value(adj, lower);
 	gtk_adjustment_changed(adj);
 	adj = gtk_scrolled_window_get_hadjustment(
 			GTK_SCROLLED_WINDOW(page->widget));
-	gtk_adjustment_set_value(adj, adj->lower);
+	gtk_adjustment_set_value(adj, lower);
 	gtk_adjustment_changed(adj);
 
 #ifdef GENERIC_UMPC
