@@ -175,7 +175,7 @@ static gint imp_mutt_delete_event( GtkWidget *widget, GdkEventAny *event, gboole
 }
 
 static gboolean imp_mutt_key_pressed( GtkWidget *widget, GdkEventKey *event, gboolean *cancelled ) {
-	if (event && event->keyval == GDK_Escape) {
+	if (event && event->keyval == GDK_KEY_Escape) {
 		*cancelled = TRUE;
 		gtk_main_quit();
 	}
