@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2003-2009 Match Grun and the Claws Mail team
+ * Copyright (C) 2003-2011 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,8 +30,6 @@
 #include <glib.h>
 #include <sys/time.h>
 #include <string.h>
-#include <ldap.h>
-#include <lber.h>
 
 #include "mgutils.h"
 #include "addritem.h"
@@ -719,18 +717,115 @@ gint ldapsvr_read_data( LdapServer *server )
 void ldapsrv_set_options (gint secs, LDAP *ld)
 {
 	static struct timeval timeout;
-	int i = LDAP_OPT_X_TLS_ALLOW;
 	int rc;
+	int i;
 	timeout.tv_sec = secs;
 	timeout.tv_usec = 0;
-	rc=ldap_set_option(NULL, LDAP_OPT_X_TLS_REQUIRE_CERT, &i);
-	debug_print("cert %s\n", ldap_err2string(rc));
-	
+#ifdef G_OS_UNIX
+	i = LDAP_OPT_X_TLS_ALLOW;
+	rc = ldap_set_option(NULL, LDAP_OPT_X_TLS_REQUIRE_CERT, &i);
+	if (ld)
+		debug_print("cert %s\n", ldaputil_get_error(ld));
+	else
+		debug_print("cert %s\n", ldap_err2string(rc));
 	/* can crash old libldaps... */
-	rc=ldap_set_option(NULL, LDAP_OPT_NETWORK_TIMEOUT, &timeout);
-	debug_print("tm %s\n", ldap_err2string(rc));
-
+	rc = ldap_set_option(NULL, LDAP_OPT_NETWORK_TIMEOUT, &timeout);
+	if (ld)
+		debug_print("tm %s\n", ldaputil_get_error(ld));
+	else
+		debug_print("tm %s\n", ldap_err2string(rc));
+#endif
 }
+
+/**
+ * Connect to LDAP server.
+ * \param  ctl Control object to process.
+ * \return LDAP Resource to LDAP.
+ */
+LDAP *ldapsvr_connect(LdapControl *ctl) {
+	LDAP *ld = NULL;
+	gint rc;
+	gint version;
+	gchar *uri = NULL;
+	gchar *pwd;
+
+	cm_return_val_if_fail(ctl != NULL, NULL);
+
+	ldapsrv_set_options (ctl->timeOut, NULL);
+	uri = g_strdup_printf("ldap%s://%s:%d",
+				ctl->enableSSL?"s":"",
+				ctl->hostName, ctl->port);
+#ifdef G_OS_UNIX
+	ldap_initialize(&ld, uri);
+#else
+	ld = ldap_sslinit(ctl->hostName, ctl->port, ctl->enableSSL);
+	if (ctl->enableSSL) {
+		ldap_get_option(ld,LDAP_OPT_SSL,(void*)&rc);
+		if ((void *)rc != LDAP_OPT_ON) {
+			debug_print("Enabling SSL\n");
+			if (ldap_set_option(ld,LDAP_OPT_SSL,LDAP_OPT_ON) != 0)
+				debug_print("Failed: %s\n", ldaputil_get_error(ld));
+		}
+	}
+#endif
+	g_free(uri);
+
+	if (ld == NULL)
+		return NULL;
+
+
+	debug_print("Got handle to LDAP host %s on port %d\n", ctl->hostName, ctl->port);
+
+	version = LDAP_VERSION3;
+	rc = ldap_set_option(ld, LDAP_OPT_PROTOCOL_VERSION, &version);
+	if (rc == LDAP_OPT_SUCCESS) {
+		ctl->version = LDAP_VERSION3;
+	} else
+		g_printerr("LDAP: Error %d (%s)\n",
+			rc, ldaputil_get_error(ld));
+#ifdef USE_LDAP_TLS
+	/* Handle TLS */
+	if (ctl->version == LDAP_VERSION3) {
+		if (ctl->enableTLS && !ctl->enableSSL) {
+			rc = ldap_start_tls_s(ld, NULL, NULL);
+			
+			if (rc != LDAP_SUCCESS) {
+				g_printerr("LDAP Error(tls): ldap_simple_bind_s: %s\n",
+					ldaputil_get_error(ld));
+				return NULL;
+			}
+		}
+	}
+#endif
+
+	/* Bind to the server, if required */
+	if (ctl->bindDN) {
+		if (* ctl->bindDN != '\0') {
+			pwd = ldapctl_get_bind_password(ctl);
+			rc = claws_ldap_simple_bind_s(ld, ctl->bindDN, pwd);
+			if (rc != LDAP_SUCCESS) {
+				g_printerr("bindDN: %s, bindPass xxx\n", ctl->bindDN);
+				g_printerr("LDAP Error(bind): ldap_simple_bind_s: %s\n",
+					ldaputil_get_error(ld));
+				g_free(pwd);
+				return NULL;
+			}
+			g_free(pwd);
+		}
+	}
+	return ld;
+}
+
+/**
+ * Disconnect to LDAP server.
+ * \param ld Resource to LDAP.
+ */
+void ldapsvr_disconnect(LDAP *ld) {
+	/* Disconnect */
+	cm_return_if_fail(ld != NULL);
+	ldap_unbind_ext(ld, NULL, NULL);
+}
+
 #endif	/* USE_LDAP */
 
 /*
