@@ -526,8 +526,7 @@ static void ldif_add_value(
 {
 	gchar *nm, *val;
 
-	nm = g_strdup( tagName );
-	g_utf8_strdown( nm, -1 );
+	nm = g_utf8_strdown( tagName, -1 );
 	if( tagValue ) {
 		val = g_strdup( tagValue );
 	}
@@ -536,19 +535,19 @@ static void ldif_add_value(
 	}
 	g_strstrip( val );
 
-	if( g_utf8_collate( nm, LDIF_TAG_COMMONNAME ) == 0 ) {
+	if( g_utf8_collate( nm, g_utf8_strdown( LDIF_TAG_COMMONNAME, -1 ) ) == 0 ) {
 		rec->listCName = g_slist_append( rec->listCName, val );
 	}
-	else if( g_utf8_collate( nm, LDIF_TAG_FIRSTNAME ) == 0 ) {
+	else if( g_utf8_collate( nm, g_utf8_strdown( LDIF_TAG_FIRSTNAME, -1 ) ) == 0 ) {
 		rec->listFName = g_slist_append( rec->listFName, val );
 	}
-	else if( g_utf8_collate( nm, LDIF_TAG_LASTNAME ) == 0 ) {
+	else if( g_utf8_collate( nm, g_utf8_strdown( LDIF_TAG_LASTNAME, -1 ) ) == 0 ) {
 		rec->listLName = g_slist_append( rec->listLName, val );
 	}
-	else if( g_utf8_collate( nm, LDIF_TAG_NICKNAME ) == 0 ) {
+	else if( g_utf8_collate( nm, g_utf8_strdown( LDIF_TAG_NICKNAME, -1 ) ) == 0 ) {
 		rec->listNName = g_slist_append( rec->listNName, val );
 	}
-	else if( g_utf8_collate( nm, LDIF_TAG_EMAIL ) == 0 ) {
+	else if( g_utf8_collate( nm, g_utf8_strdown( LDIF_TAG_EMAIL, -1 ) ) == 0 ) {
 		rec->listAddress = g_slist_append( rec->listAddress, val );
 	}
 	else {
@@ -756,30 +755,30 @@ static void ldif_hash_add_list( GHashTable *table, GSList *list ) {
 		gchar *tag = node->data;
 		if( ! g_hash_table_lookup( table, tag ) ) {
 			Ldif_FieldRec *rec = NULL;
-			gchar *key = g_strdup( tag );
+			gchar *key = g_utf8_strdown( tag, -1 );
 
 			rec = ldif_create_fieldrec( tag );
-			if( g_utf8_collate( tag, LDIF_TAG_DN ) == 0 ) {
+			if( g_utf8_collate( key, LDIF_TAG_DN ) == 0 ) {
 				rec->reserved = rec->selected = TRUE;
 				rec->userName = g_strdup( "dn" );
 			}
-			else if( g_utf8_collate( tag, LDIF_TAG_COMMONNAME ) == 0 ) {
+			else if( g_utf8_collate( key, g_utf8_strdown( LDIF_TAG_COMMONNAME, -1 ) ) == 0 ) {
 				rec->reserved = rec->selected = TRUE;
 				rec->userName = g_strdup( _( "Display Name" ) );
 			}
-			else if( g_utf8_collate( tag, LDIF_TAG_FIRSTNAME ) == 0 ) {
+			else if( g_utf8_collate( key, g_utf8_strdown( LDIF_TAG_FIRSTNAME, -1 ) ) == 0 ) {
 				rec->reserved = rec->selected = TRUE;
 				rec->userName = g_strdup( _( "First Name" ) );
 			}
-			else if( g_utf8_collate( tag, LDIF_TAG_LASTNAME ) == 0 ) {
+			else if( g_utf8_collate( key, g_utf8_strdown( LDIF_TAG_LASTNAME, -1 ) ) == 0 ) {
 				rec->reserved = rec->selected = TRUE;
 				rec->userName = g_strdup( _( "Last Name" ) );
 			}
-			else if( g_utf8_collate( tag, LDIF_TAG_NICKNAME ) == 0 ) {
+			else if( g_utf8_collate( key, g_utf8_strdown( LDIF_TAG_NICKNAME, -1 ) ) == 0 ) {
 				rec->reserved = rec->selected = TRUE;
 				rec->userName = g_strdup( _( "Nick Name" ) );
 			}
-			else if( g_utf8_collate( tag, LDIF_TAG_EMAIL ) == 0 ) {
+			else if( g_utf8_collate( key, g_utf8_strdown( LDIF_TAG_EMAIL, -1 ) ) == 0 ) {
 				rec->reserved = rec->selected = TRUE;
 				rec->userName = g_strdup( _( "Email Address" ) );
 			}
