@@ -540,7 +540,7 @@ gchar *mutt_find_file( void ) {
 	homedir = get_home_dir();
 	if( ! homedir ) return g_strdup( "" );
 
-	strcpy( str, homedir );
+	strncpy( str, homedir, WORK_BUFLEN );
 	len = strlen( str );
 	if( len > 0 ) {
 		if( str[ len-1 ] != G_DIR_SEPARATOR ) {
@@ -548,7 +548,7 @@ gchar *mutt_find_file( void ) {
 			str[ ++len ] = '\0';
 		}
 	}
-	strcat( str, MUTT_HOME_FILE );
+	strncat( str, MUTT_HOME_FILE, WORK_BUFLEN );
 
 	/* Attempt to open */
 	if( ( fp = g_fopen( str, "rb" ) ) != NULL ) {
