@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 the Claws Mail Team
+ * Copyright (C) 1999-2011 the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,9 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#if GTK_CHECK_VERSION(3, 0, 0)
+#include <gtk/gtkx.h>
+#endif
 #include <gdk/gdkx.h>
 
 #include "common/claws.h"
@@ -60,7 +63,11 @@ static GtkWidget *dillo_get_widget(MimeViewer *_viewer)
 	return GTK_WIDGET(viewer->widget);
 }
 
+#if !GTK_CHECK_VERSION(3, 0, 0)
 static gboolean socket_destroy_cb(GtkObject *object, gpointer data)
+#else
+static gboolean socket_destroy_cb(GtkObject *object, gpointer data)
+#endif
 {
 	DilloViewer *viewer = (DilloViewer *) data;
 	debug_print("Destroyed dillo socket %p\n", viewer->socket);
