@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -664,9 +664,11 @@ gint pop3_write_uidl_list(Pop3Session *session)
 	gchar *sanitized_uid = g_strdup(session->ac_prefs->userid);
 	
 	subst_for_filename(sanitized_uid);
-	
 
-	if (!session->uidl_is_valid) return 0;
+	if (!session->uidl_is_valid) {
+		g_free(sanitized_uid);
+		return 0;
+	}
 
 	path = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S,
 			   "uidl", G_DIR_SEPARATOR_S,
