@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,5 +25,7 @@
 void prefs_actions_read_config		(void);
 void prefs_actions_write_config		(void);
 void prefs_actions_open			(MainWindow	*mainwin);
+void prefs_actions_rename_path		(const gchar *old_path,
+					 const gchar *new_path);
 
 #endif /* __PREFS_ACTIONS_H__ */
