@@ -444,7 +444,7 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"thread_by_subject", "TRUE", &prefs_common.thread_by_subject, P_BOOL,
 	 NULL, NULL, NULL},
-	{"date_format", N_("%y/%m/%d(%a) %H:%M"), &prefs_common.date_format,
+	{"date_format", N_("%x(%a) %H:%M"), &prefs_common.date_format,
 	 P_STRING, NULL, NULL, NULL},
 	{"msgview_date_format", "FALSE", &prefs_common.msgview_date_format, P_BOOL,
 	 NULL, NULL, NULL},
@@ -652,6 +652,8 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"messagewin_height", "540", &prefs_common.msgwin_height, P_INT,
 	 NULL, NULL, NULL},
+	{"mimeview_tree_height", "60", &prefs_common.mimeview_tree_height, P_INT,
+	 NULL, NULL, NULL},	 
 	{"sourcewin_width", "600", &prefs_common.sourcewin_width, P_INT,
 	 NULL, NULL, NULL},
 	{"sourcewin_height", "500", &prefs_common.sourcewin_height, P_INT,
@@ -678,6 +680,8 @@ static PrefParam param[] = {
 	{"compose_height", "470", &prefs_common.compose_height, P_INT,
 	 NULL, NULL, NULL},
 #endif
+	{"compose_notebook_height", "130", &prefs_common.compose_notebook_height, P_INT,
+	 NULL, NULL, NULL},
 	{"compose_x", "0", &prefs_common.compose_x, P_INT,
 	 NULL, NULL, NULL},
 	{"compose_y", "0", &prefs_common.compose_y, P_INT,
@@ -740,6 +744,8 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"respect_flowed_format", "FALSE", &prefs_common.respect_flowed_format, P_BOOL,
 	 NULL, NULL, NULL},
+	{"show_all_headers", "FALSE", &prefs_common.show_all_headers, P_BOOL,
+	 NULL, NULL, NULL},
 
 	{"show_other_header", "FALSE", &prefs_common.show_other_header, P_BOOL,
 	 NULL, NULL, NULL},
@@ -803,6 +809,8 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"nextunreadmsg_dialog", "1", &prefs_common.next_unread_msg_dialog, P_ENUM,
 	 NULL, NULL, NULL},
+	{"summary_from_show", "0", &prefs_common.summary_from_show, P_ENUM,
+	 NULL, NULL, NULL},
 
 	{"pixmap_theme_path", DEFAULT_PIXMAP_THEME, 
 	 &SPECIFIC_PREFS.pixmap_theme_path, P_STRING,
@@ -1062,8 +1070,6 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"stripes_color_offset", "4000", &prefs_common.stripes_color_offset, P_INT,
 	 NULL, NULL, NULL},
-	{"enable_dotted_lines", "FALSE", &prefs_common.enable_dotted_lines, P_BOOL,
-	 NULL, NULL, NULL},
 	{"enable_hscrollbar", "TRUE", &prefs_common.enable_hscrollbar, P_BOOL,
 	 NULL, NULL, NULL},
 	{"folderview_vscrollbar_policy", "0",
