@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2009 Colin Leroy <colin@colino.net> & The Claws Mail Team
+ * Copyright (C) 2005-2011 Colin Leroy <colin@colino.net> & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,7 +100,7 @@ static void prefs_receive_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	GtkWidget *hbox_autochk;
 	GtkWidget *checkbtn_autochk;
-	GtkObject *spinbtn_autochk_adj;
+	GtkAdjustment *spinbtn_autochk_adj;
 	GtkWidget *spinbtn_autochk;
 	GtkWidget *label_autochk2;
 	GtkWidget *checkbtn_chkonstartup;
