@@ -671,7 +671,7 @@ static gboolean prefs_summary_column_key_pressed(GtkWidget *widget,
 						 GdkEventKey *event,
 						 gpointer data)
 {
-	if (event && event->keyval == GDK_Escape)
+	if (event && event->keyval == GDK_KEY_Escape)
 		summary_col.finished = TRUE;
 	return FALSE;
 }
@@ -806,7 +806,8 @@ static void drag_data_get(GtkTreeView *tree_view, GdkDragContext *context,
 			   -1);
 
 	/* send the type */
-	gtk_selection_data_set(data, data->target, 8, (gchar *) &type, sizeof type);
+	gtk_selection_data_set(data, gtk_selection_data_get_target(data), 8,
+		(gchar *) &type, sizeof type);
 }
 
 static void drag_data_received(GtkTreeView *tree_view, GdkDragContext *context,
@@ -876,7 +877,7 @@ static void drag_data_received(GtkTreeView *tree_view, GdkDragContext *context,
 		gtk_tree_selection_get_selected(gtk_tree_view_get_selection(
 						GTK_TREE_VIEW(source)),
 						&sel_model, &isel);
-		type = *((gint *) data->data);
+		type = *((gint *) gtk_selection_data_get_data(data));
 		name = gettext(col_name[type]);
 		gtk_list_store_remove(GTK_LIST_STORE(sel_model), &isel);
 
