@@ -322,8 +322,8 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 			inc_pop_before_smtp(ac_prefs);
 		}
 
-		g_snprintf(buf, sizeof(buf), _("Connecting to SMTP server: %s ..."),
-			   ac_prefs->smtp_server);
+		g_snprintf(buf, sizeof(buf), _("Account '%s': Connecting to SMTP server: %s ..."),
+				ac_prefs->account_name, ac_prefs->smtp_server);
 		progress_dialog_set_label(dialog->dialog, buf);
 		log_message(LOG_PROTOCOL, "%s\n", buf);
 
@@ -509,7 +509,7 @@ static gint send_send_data_progressive(Session *session, guint cur_len,
 		(dialog->dialog, (total_len == 0) ? 0 : (gfloat)cur_len / (gfloat)total_len);
 
 	if (mainwin) {
-		if (!gtkut_widget_get_visible(mainwin->progressbar))	
+		if (!gtk_widget_get_visible(mainwin->progressbar))	
 			gtk_widget_show(mainwin->progressbar);
 		gtk_progress_bar_set_fraction
 			(GTK_PROGRESS_BAR(mainwin->progressbar),
