@@ -34,7 +34,6 @@
 #include "manage_window.h"
 #include "utils.h"
 #include "mainwindow.h"
-#include "gtksctree.h"
 #include "alertpanel.h"
 #include "sslcertwindow.h"
 #include "prefs_common.h"
@@ -348,7 +347,7 @@ static void ssl_manager_load_certs (void)
 		port = get_port(d->d_name);
 		fp = get_fingerprint(d->d_name);
 		
-		cert = ssl_certificate_find_lookup(server, atoi(port), fp, FALSE);
+		cert = ssl_certificate_find(server, atoi(port), fp);
 
 		ssl_manager_list_view_insert_cert(manager.certlist, NULL, 
 						  server, port, cert);
@@ -375,7 +374,7 @@ static void ssl_manager_close_cb(GtkWidget *widget,
 
 static gboolean key_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
-	if (event && event->keyval == GDK_Escape)
+	if (event && event->keyval == GDK_KEY_Escape)
 		ssl_manager_close();
 	return FALSE;
 }
