@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,14 +57,15 @@ GtkWidget *statusbar_create(void)
 	statusbar = gtk_statusbar_new();
 	gtk_widget_set_size_request(statusbar, 1, -1);
 	statusbar_list = g_list_append(statusbar_list, statusbar);
+#if !GTK_CHECK_VERSION(3, 0, 0)
 	gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(statusbar), 
 					  FALSE);
-	gtk_container_set_border_width(GTK_CONTAINER(statusbar), 1);
-#if GTK_CHECK_VERSION (2, 19, 1)
-	child = gtk_statusbar_get_message_area(GTK_STATUSBAR(statusbar));
 #else
-	child = GTK_STATUSBAR(statusbar)->label;
+	gtk_window_set_has_resize_grip(GTK_WINDOW(statusbar), 
+					  FALSE);
 #endif
+	gtk_container_set_border_width(GTK_CONTAINER(statusbar), 1);
+	child = gtk_statusbar_get_message_area(GTK_STATUSBAR(statusbar));
 	parent = gtk_widget_get_parent(child);
 	gtk_container_remove(GTK_CONTAINER(parent), g_object_ref(child));
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -250,7 +251,7 @@ void statusbar_progress_all (gint done, gint total, gint step)
 		gtk_progress_bar_set_text(progressbar, buf);
 		gtk_progress_bar_set_fraction(progressbar,
 			 (total == 0) ? 0 : (gfloat)done / (gfloat)total);
-		if (!gtkut_widget_get_visible(GTK_WIDGET(progressbar)))
+		if (!gtk_widget_get_visible(GTK_WIDGET(progressbar)))
 			gtk_widget_show(GTK_WIDGET(progressbar));
 	} else if (total == 0) {
 		gtk_progress_bar_set_text(progressbar, "");
