@@ -177,8 +177,8 @@ struct {
 	gchar *index_str;
 	const gchar *descr;
 } toolbar_text [] = {
-	{ "A_RECEIVE_ALL",   	N_("Receive Mail on all Accounts")         },
-	{ "A_RECEIVE_CUR",   	N_("Receive Mail on current Account")      },
+	{ "A_RECEIVE_ALL",   	N_("Receive Mail from all Accounts")       },
+	{ "A_RECEIVE_CUR",   	N_("Receive Mail from current Account")    },
 	{ "A_SEND_QUEUED",   	N_("Send Queued Messages")                 },
 	{ "A_COMPOSE_EMAIL", 	N_("Compose Email")                        },
 	{ "A_COMPOSE_NEWS",  	N_("Compose News")                         },
@@ -361,7 +361,7 @@ static void toolbar_parse_item(XMLFile *file, ToolbarType source)
 			g_free(item->file);
 			item->file = g_strdup("trash_btn");
 			g_free(item->text);
-			item->text = g_strdup(_("Trash"));
+			item->text = g_strdup(Q_("Toolbar|Trash"));
 			rewrite = TRUE;
 		}
 		if (item->index == -1 && !strcmp(value, "A_SYL_ACTIONS")) {
@@ -393,10 +393,10 @@ const gchar *toolbar_get_short_text(int action) {
 	case A_COMPOSE_NEWS: 	return Q_("Toolbar|Compose");
 	case A_REPLY_MESSAGE: 	return _("Reply");
 	case A_REPLY_ALL: 	return _("All");
-	case A_REPLY_SENDER: 	return _("Sender");
+	case A_REPLY_SENDER: 	return Q_("Toolbar|Sender");
 	case A_REPLY_ML: 	return _("List");
 	case A_FORWARD: 	return _("Forward");
-	case A_TRASH: 		return _("Trash");
+	case A_TRASH: 		return Q_("Toolbar|Trash");
 	case A_DELETE_REAL:	return _("Delete");
 	case A_LEARN_SPAM: 	return _("Spam");
 	case A_GOTO_PREV: 	return _("Prev");
@@ -1896,12 +1896,12 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 			break;
 		case A_RECEIVE_ALL:
 			TOOLBAR_MENUITEM(item,icon_wid,toolbar_item->text,
-				_("Receive Mail on all Accounts"),
-				_("Receive Mail on selected Account"));
+				_("Receive Mail from all Accounts"),
+				_("Receive Mail from selected Account"));
 			toolbar_data->getall_btn = item;
 			break;
 		case A_RECEIVE_CUR:
-			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text, _("Receive Mail on current Account"));
+			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text, _("Receive Mail from current Account"));
 			toolbar_data->get_btn = item;
 			break;
 		case A_SEND_QUEUED:
